import axios from 'axios'
import { updateToken } from './common'
import { Toast } from 'vant'
import selfApi from './apiList'
// 创建 axios 实例
const service = axios.create({
    headers: { 'Content-Type': 'application/json' },
    timeout: 30000
})

// 设置 post、put 默认 Content-Type
service.defaults.headers.post['Content-Type'] = 'application/json'
service.defaults.headers.put['Content-Type'] = 'application/json'

// 添加请求拦截器
service.interceptors.request.use(
    config => {
        // console.log(config, 'config-----------')
        if (config.method === 'post' || config.method === 'put') {
            // post、put 提交时，将对象转换为string, 为处理后台解析问题
            config.data = JSON.stringify(config.data)
        }
        // 请求发送前进行处理
        // console.log("请求发送前进行处理", config)
        return config
    }, error => {
        // 请求错误处理
        // console.log("请求发送前---请求错误处理", error)
        return Promise.reject(error)
    }
)

// 添加响应拦截器
service.interceptors.response.use(
    response => {
        const { data, config } = response
        console.log('添加响应拦截器', response)
        if (data.meta.code === 400) {
            console.log('===== token过期 =====')
            const promisefresh = new Promise(function (resolve, reject) {
                updateToken(() => {
                    config.headers.token = window.localStorage.getItem('token')
                    axios.request(response.config).then(res => {
                        const curData = res.data
                        if (curData.meta.code === 200) {
                            resolve(curData)
                        } else {
                            // window.localStorage.removeItem('token')
                            // window.localStorage.removeItem('status')
                            resolve(curData)
                        }
                    })
                }, (err) => {
                    resolve(err)
                    window.localStorage.clear()
                    Toast('身份失效，请重新登录')
                    window.document.location = selfApi.WINDOWHREF_LOGIN // url-
                    console.log('错误--------', err)
                })
            })
            return promisefresh
        } else {
            return data
        }
    },
    error => {
        let info = {}
        if (!error.response) {
            info = {
                code: 5000,
                message: 'Network Error'
            }
        } else {
            const { status, statusText, data } = error.response
            // 此处整理错误信息格式
            info = {
                code: status,
                data: data,
                message: statusText
            }
        }
        // console.log("添加响应拦截器err", error, info)
        return Promise.reject(info)
    }
)

/**
* 创建统一封装过的 axios 实例
* @return {AxiosInstance}
*/
export default function () {
    return service
}